% --------------------------------------------------------------------------
%  Static analysis  of a spring-mass system  with MANLAB
%  -------------------------------------------------------------------------
%
%      \|   spring 1
%      \|------------O mass  
%      \|            |
%                    | spring 2
%                    |    
%                  - - -
%                  \ \ \
%
%   u1(t) : x displacement of the mass 
%   u2(t) : y displacement of the mass
%
%   e1= u1 + 1/2 (u1^2 + u2^2)  strain for spring 1 (Green-lagrange)
%   e2= u2 + 1/2 (u1^2 + u2^2)  strain for spring 2
%
%   N1= k1 e1    spring force (ki : stiffness)
%   N2= k2 e2 
%
%   W= 1/2 k1  e1^2 + 1/2 k2  e2^2  strain energy
%
%   F1, F2 applied force on the mass
%   lambda : force amplitude parameter
%   
%   P = W - (lambda F1 u1 + lambda F2 u2)    Potential energy
%
%   static equations     
%   ---------------
%    d P/d u1 =0    --->     N1 (1+u1) + N2 (u1)   - lambda F1  = 0
%    d P/d u2 =0    --->     N1 (u2)   + N2 (1+u2) - lambda F2  = 0
%
%                            N1  - k1 u1 - k1/2 (u1^2 + u2^2)   =  0
%                            N2  - k2 u2 - k2/2 (u1^2 + u2^2)   =  0
%
%   U = [ u1, u2 ,  N1 , N2 , lambda ]  (Neq=4) 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  for the stability analysis, we consider the following ODE system
%
%   m u1''  +  N1 (1+u1) + N2 (u1)     - lambda F1 = 0 
%   m u2''  +  N1 (u2)   + N2 (1+u2)   - lambda F2 = 0 
%
%   We transform into first order system by introducing   v1 = u1' and v2 = u2'
%                  
%
%    u1'  =     v1
%    u2'  =     v2 
%    v1'  = -1/m ( N1 +  u1 (N1+N2) - lambda F1)
%    v2'  = -1/m ( N2 +  u2 (N1+N2) - lambda F2)  
%    0    =  N1 - k1 u1  - k1/2 (u1^2 + u2^2)
%    0    =  N2 - k2 u2  - k2/2 (u1^2 + u2^2)
%
%   The jacobain matrix reads
%
%
%

%--------------------------------------------------------------------------

close all
clear all
clc
 k1=1;
 k2=2;
 F1=-1;
 F2=1;
 
ninc=5;                           
Diamanlab('sys'     ,DRSTAT(k1,k2,F1,F2,ninc), ...
          'order'   ,20, ...
          'U0value' ,zeros(ninc,1), ...
          'displayvariables',[  1  5 ; 2  5 ]);      % DiaMANLAB run 

