% 
% ---------------------------------------------------------------------
% ELASTICA : the clamped-rotulated case  a moment load
% ---------------------------------------------------------------------
% 
%   the state vector 
%   ----------------
%
%   Z(s)= [x(s) ; y(s) ; theta(s) ; m(s) ]  (Nz=4) on s = [0,1]
%
%   the differential-algebraic equation system (here an ODE system)
%   ------------------------------------------------------------------
%    
%   
%      x'   = cos(theta)  
%      y'   = sin(theta)  
%    theta' = m         
%       m'  = -4 pi^2 (  -Ry cos(theta) ) =0
%
%
%    parameters :  mu=[  Ry  ] (Nmu=1) 
%    ------------------------------------------------
%
%    Ry  transversal reaction at s=1 (rotule)
%   
%
%    Boundary conditions  (Nbc=5)
%    -------------------
%    X(0)=0
%    y(0)=0 
%    theta(0)=0 
%
%    y(1)=0
%    m(1)= 2*pi*lambda
% 
%  ---------------------------------------------------------------------------------
clc
clear all

 Nz=  4;       % size of the state vector Z
 Nmu= 1;     % parameters number
 Nbc= 5;     % boundary condition number
 
 Nelmt=4;    % element number
 Npoly=3;    % degre of polynomial interpolation
 
 L=1;
 s=0:L/(Npoly*Nelmt): L;
 x    = s ;
 y    = zeros(1,Npoly*Nelmt+1);
 theta= zeros(1,Npoly*Nelmt+1);
 m    = zeros(1,Npoly*Nelmt+1);


 %Intitialization of the start solution U 
 Nzd =(Npoly*Nelmt+1)*Nz;
 Z0 = zeros(Nzd,1);
 Z0(1:Nz:Nzd)=x;
 Z0(2:Nz:Nzd)=y;
 Z0(3:Nz:Nzd)=theta+0.0001;
 Z0(4:Nz:Nzd)=m;

 mu0=[ 0  ];

 lambda0= 0;

 U0=[Z0 ; mu0 ; lambda0];
 ninc = Nzd+ Nmu + 1;   % number of discrete unknowns (size of U0)

%                lambda   x(1)       lambda theta(1)      
 dispvars = [   ninc   Nzd-Nz+1  ;   ninc  Nzd-Nz+3 ]; 
 Diamanlab('sys',BVPCOLLO(Nz,Nmu,Nbc,Nelmt,Npoly,ninc), 'order', 20, 'U0value',U0, 'displayvariables', dispvars); 
 
