function [U, Amax,BifData]=ANMserieBif(sys,Ubif,Ut1,Ut2)
%Compute taylor series at  Ubif for the branch along Ut1 tangent

global Ck
Ck=sys.order;


Norder = get(sys,'order');
ninc   = get(sys,'ninc');


U2 = zeros(ninc,1);
Up = zeros(ninc,1);

Usol=zeros(ninc+1,1);
F  = zeros(ninc+1,1);

%Tangent matrix at the bifurcation point
dRdU=Jacobian(sys, Ubif);

% left nul vector phi computed with two inverse iterations
Kt=dRdU(:,1:end-1)';
phi=Kt\ones(get(sys, 'neq'),1);
phi=phi/norm(phi);
phi=Kt\phi;
phi=phi/norm(phi);

%Nul right vector of the matrix [dRdU; Ut1']
Umode = Ut2 - ( (Ut1'*Ut2)/(Ut1'*Ut1)  ) *Ut1;
K=[dRdU phi; [Ut1; 0]'; [Umode; 0]'];

% Fast LU factorization
[LK, UK,pK,qK]=lu(K,'vector');

% Initialization of Taylor object
U = Taylor(Norder+1,Ubif);

% Order 1
U = set(U, 'coef1', Ut1);

% prepare some constant
U=set(U,'coefk',Umode, 2);
U=set(U,'coefk',zeros(size(Ubif)), 3);
Ck=3;
%F12=get(R(sys,U), 'coefk',3);
F12=Fpnl(sys,U,3);
ProjF12= phi'*F12


% Second Order   
% ------------
%rhs for order 2

U=set(U,'coefk',zeros(size(Ubif)), 2);
Ck=2;
F    =  [ -Fpnl(sys,U,2) ; 0 ; 0 ] ;

Usol(qK) = UK\(LK\ F(pK)) ;  % solving 
U2star=Usol(1:ninc,1);
U=set(U,'coefk',U2star, 2);

% Compute alpha, finish U2 and prepare rhs for order 3

U=set(U,'coefk',zeros(size(Ubif)), 3);
Ck=3;
%F3nlE =  get(R(sys,U), 'coefk',3)   ;
F3nlE =  Fpnl(sys,U,3)   ;
alpha =  - (phi'*F3nlE)/ProjF12 
U2    =  U2star + alpha * Umode;
Fknl  = F3nlE + alpha * F12;

U =set(U,'coefk',U2,2); %

%%  
% Next Orders 
%------------

for p=3:Norder

  F = [ -Fknl ; 0 ; 0 ] ;

% Use LU-factors for inversion of K
  Usol(qK) = UK\(LK\ F(pK)) ;
  Upstar=Usol(1:ninc);
  U =set(U,'coefk',Upstar,p); %
       
% Compute alpha, finish Up and prepare rhs for order p+1

  U =set(U,'coefk',zeros(size(Ubif)),p+1);
  Ck=p+1;
  FknlE = Fpnl(sys,U,p+1);
  alpha =  - (phi'*FknlE)/ProjF12;
  Up    = Upstar + alpha * Umode;
  Fknl  = FknlE + alpha * F12 ; 
  U =set(U,'coefk',Up,p); %

end

BifData.status='nothing';
Amax = (sys.ANMthreshold/norm(Fknl))^(1/(sys.order+1));    

