function [U] = NRcorrection(sys,U)
% performs Newton-Raphson correction

iter = 0;

NRthreshold=get(sys,'NRthreshold'); NRitemax=get(sys,'NRitemax');
Ucor  = zeros(sys.ninc,1);
Usave = U;

Rnew=R(sys,U);
normR =norm(Rnew);
if (normR > NRthreshold)
  disp(['N-R: Before correction ||R(Uj)||=' num2str(normR); ] );
end

while (normR > NRthreshold) && (iter < NRitemax)
  iter = iter + 1;
  dRdU = Jacobian(sys,U); Ut = tangentvector(sys,U,dRdU); 
  K = [dRdU ; sparse(Ut')];
  % Fast LU-factorization
  [LK,UK,pK,qK] = lu(K,'vector');
  RN=[Rnew;0];  
  % Back substitution
  Ucor(qK) = UK\(LK\RN(pK));
  U=U-Ucor;
  Rnew=R(sys,U); normR = norm(Rnew);
  disp(['N-R: After correction' num2str(iter) ': ||R(Uj)||=' num2str(normR); ] );
end

if isnan(normR)
  warndlg('Correction failed: NaN values. Back to the previous correct point.','Correction','on');
  U = Usave;
end

if iter == NRitemax
  warndlg('Correction failed: Max number of iterations is reached. Back to the previous correct point.','Correction','on');
  U = Usave;
end
